@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 
-import os
+import sys
 from argparse import ArgumentParser
 import onnx
 from typing import Optional, List
@@ -32,18 +32,16 @@ class Color:
 
 
 def extraction(
-    input_onnx_file_path: str,
     input_op_names: List[str],
     output_op_names: List[str],
+    input_onnx_file_path: Optional[str] = '',
+    onnx_graph: Optional[onnx.ModelProto] = None,
     output_onnx_file_path: Optional[str] = '',
 ) -> onnx.ModelProto:
 
     """
     Parameters
     ----------
-    input_onnx_file_path: str
-        Input onnx file path.
-
     input_op_names: List[str]
         List of OP names to specify for the input layer of the model.\n\
         Specify the name of the OP, separated by commas.\n\
@@ -54,6 +52,16 @@ def extraction(
         Specify the name of the OP, separated by commas.\n\
         e.g. ['ddd','eee','fff']
 
+    input_onnx_file_path: Optional[str]
+        Input onnx file path.\n\
+        Either input_onnx_file_path or onnx_graph must be specified.\n\
+        onnx_graph If specified, ignore input_onnx_file_path and process onnx_graph.
+
+    onnx_graph: Optional[onnx.ModelProto]
+        onnx.ModelProto.\n\
+        Either input_onnx_file_path or onnx_graph must be specified.\n\
+        onnx_graph If specified, ignore input_onnx_file_path and process onnx_graph.
+
     output_onnx_file_path: Optional[str]
         Output onnx file path.\n\
         If not specified, .onnx is not output.\n\
@@ -65,22 +73,30 @@ def extraction(
         Extracted onnx ModelProto
     """
 
-    tmp_onnx_file = ''
-    if not output_onnx_file_path:
-        tmp_onnx_file = 'extracted.onnx'
-    else:
-        tmp_onnx_file = output_onnx_file_path
+    if not input_onnx_file_path and not onnx_graph:
+        print(
+            f'{Color.RED}ERROR:{Color.RESET} '+
+            f'One of input_onnx_file_path or onnx_graph must be specified.'
+        )
+        sys.exit(1)
 
-    onnx.utils.extract_model(
-        input_onnx_file_path,
-        tmp_onnx_file,
+    # Load
+    graph = None
+    if not onnx_graph:
+        graph = onnx.load(input_onnx_file_path)
+    else:
+        graph = onnx_graph
+
+    # Extract
+    extractor = onnx.utils.Extractor(graph)
+    extracted_graph = extractor.extract_model(
         input_op_names,
-        output_op_names
+        output_op_names,
     )
 
-    extracted_graph = onnx.load(tmp_onnx_file)
-    if not output_onnx_file_path:
-        os.remove(tmp_onnx_file)
+    # Save
+    if output_onnx_file_path:
+        onnx.save(extracted_graph, output_onnx_file_path)
 
     return extracted_graph
 
@@ -132,4 +148,4 @@ def main():
 
 
 if __name__ == '__main__':
-    main()
\ No newline at end of file
+    main()
